@@ -445,7 +445,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub async fn initiate_payment_endpoint(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
-                body: TypedBody<<super::#context_type_name<'_> as PaymentProcessor>::InitiateArgs>,
+                body: TypedBody<Option<<super::#context_type_name<'_> as PaymentProcessor>::ProcessArgs>>,
             ) -> Result<HttpResponseOk<Checkout>, HttpError> {
                 let path_params = path.into_inner();
                 let args = body.into_inner();
